#
# spec file for package python-CacheControl
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python3-CacheControl
Version:        0.12.6
Release:        bp156.1.1
Summary:        Caching library for Python requests
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/ionrock/cachecontrol
Source:         https://github.com/ionrock/cachecontrol/archive/v%{version}.tar.gz#/CacheControl-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python3-msgpack
Requires:       python3-requests
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python3-lockfile >= 0.9
Suggests:       python3-redis >= 2.10.5
BuildArch:      noarch
# SECTION test requirements
## cherrypy is python3 only from 18.x series
BuildRequires:  python3-CherryPy
BuildRequires:  python3-lockfile >= 0.9
BuildRequires:  python3-mock
BuildRequires:  python3-msgpack
BuildRequires:  python3-pytest
BuildRequires:  python3-redis >= 2.10.5
BuildRequires:  python3-requests
# /SECTION
%python_subpackages

%description
CacheControl is a port of the caching algorithms in httplib2 for use with
requests session object.

%prep
%setup -q -n cachecontrol-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/doesitcache
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_file_cache_recognizes_consumed_file_handle uses httpbin.org directly
PYTHONPATH=%{buildroot}%{python3_sitelib} py.test-%{python3_bin_suffix} -v -k 'not test_file_cache_recognizes_consumed_file_handle'

%post
%python_install_alternative doesitcache

%postun
%python_uninstall_alternative doesitcache

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%python_alternative %{_bindir}/doesitcache
%{python_sitelib}/*

%changelog
* Wed Feb 21 2024 Max Lin <mlin@suse.com>
- Implement update-alternatives
* Thu Jan  2 2020 John Vandenberg <jayvdb@gmail.com>
- Drop merged pytest4.patch
- Add explanation of one test failure
- Remove mention of httplib2 from package summary
- Update to v0.12.6
  * Test if cache is None before falling back to DictCache
  * Fixed body in 304 response to etag request
  * Added check for "*" value in Vary header
  * Make v4 cache compatible with msgpack 1.0 in the future
* Fri Nov  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with new pytest:
  * pytest4.patch
* Wed Sep 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Restrict pytest to 3.x as newer released do not work with
  this package
* Fri Apr  5 2019 Tomáš Chvátal <tchvatal@suse.com>
- Run tests only under py3 as CherryPy is available only there
* Mon Mar 25 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite, with two tests currently failing
- Trim description, removing irrelevant information about httplib2
- Recommend lockfile, as a lightweight dependency needed for FileCache,
  which is a primary use of CacheControl.
* Thu Feb 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.12.5:
  * various test fixes
  * few crasher fixes
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Mar 23 2018 tbechtold@suse.com
- Initial packaging (version 0.12.4)
